Crate kcr_operator_cluster_x_k8s_io

Crate kcr_operator_cluster_x_k8s_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the operator.cluster.x-k8s.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

operator.cluster.x-k8s.io/v1alpha1

  • BootstrapProvider
  • ControlPlaneProvider
  • CoreProvider
  • InfrastructureProvider

operator.cluster.x-k8s.io/v1alpha2

  • AddonProvider
  • BootstrapProvider
  • ControlPlaneProvider
  • CoreProvider
  • InfrastructureProvider

Modules

v1alpha1
v1alpha2